@@ -34,7 +34,7 @@ class ImsClient(AbstractClient):
 
         ### 接口功能说明：
         - 支持对图片文件或链接进行检测，通过深度学习技术，识别可能令人反感、不安全或不适宜的违规图片内容；
-        - 支持对GIF图/长图进行截帧或拆分检测；
+        - 支持对长图进行拆分检测；
         - 支持识别多种违规场景，包括：低俗、违法违规、色情、广告等场景；
         - 支持多种物体检测（实体、广告台标、二维码等）及图片中文本的OCR文本识别；
         - 支持根据不同的业务场景配置自定义的审核策略；
@@ -46,8 +46,10 @@ class ImsClient(AbstractClient):
         - 图片文件分辨率支持：建议**分辨率大于256x256**，否则可能会影响识别效果；
         - 图片文件支持格式：PNG、JPG、JPEG、BMP、GIF、WEBP格式；
         - 图片文件链接支持的传输协议：HTTP、HTTPS；
-        - 若传入图片文件的访问链接，则需要注意**图片下载时间限制为3秒**，为保障被检测图片的稳定性和可靠性，建议您使用腾讯云COS存储或者CDN缓存等；
+        - 若传入图片文件的访问链接，则需要注意**图片异步接口下载超时时间为15秒，失败后重试1次为3 秒，共18秒下载时间**，为保障被检测图片的稳定性和可靠性，建议您使用腾讯云COS存储或者CDN缓存等；
         - 默认接口请求频率限制：**20次/秒**，超过此调用频率则会报错。
+        - ### 接口回调格式：
+        - 图片异步检测接口回调格式同[图片同步检测接口输出参数](https://cloud.tencent.com/document/product/1125/53273#3.-.E8.BE.93.E5.87.BA.E5.8F.82.E6.95.B0)
 
         :param request: Request instance for CreateImageModerationAsyncTask.
         :type request: :class:`tencentcloud.ims.v20201229.models.CreateImageModerationAsyncTaskRequest`
@@ -77,7 +79,7 @@ class ImsClient(AbstractClient):
 
         ### 接口功能说明：
         - 支持对图片文件或链接进行检测，通过深度学习技术，识别可能令人反感、不安全或不适宜的违规图片内容；
-        - 支持对GIF图/长图进行截帧或拆分检测；
+        - 支持对长图进行拆分检测；
         - 支持识别多种违规场景，包括：低俗、违法违规、色情、广告等场景；
         - 支持多种物体检测（实体、广告台标、二维码等）及图片中文本的OCR文本识别；
         - 支持根据不同的业务场景配置自定义的审核策略；
